# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.smartbch_contract_api import SmartbchContractApi  # noqa: E501
from mainnet.rest import ApiException


class TestSmartbchContractApi(unittest.TestCase):
    """SmartbchContractApi unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.smartbch_contract_api.SmartbchContractApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_smart_bch_contract_call(self):
        """Test case for smart_bch_contract_call

        Call a SmartBch contract function  # noqa: E501
        """
        pass

    def test_smart_bch_contract_create(self):
        """Test case for smart_bch_contract_create

        Create a SmartBch contractId  # noqa: E501
        """
        pass

    def test_smart_bch_contract_deploy(self):
        """Test case for smart_bch_contract_deploy

        Request to deploy a SmartBch contract  # noqa: E501
        """
        pass

    def test_smart_bch_contract_estimate_gas(self):
        """Test case for smart_bch_contract_estimate_gas

        Estimate the gas for a contract interaction function given the arguments  # noqa: E501
        """
        pass

    def test_smart_bch_contract_info(self):
        """Test case for smart_bch_contract_info

        Get information about a SmartBch contract from the contractId  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class TokenGenesisRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'wallet_id': 'str',
        'amount': 'float',
        'capability': 'str',
        'commitment': 'str',
        'cashaddr': 'str',
        'value': 'float',
        'send_requests': 'AnyOfSendRequestItemarrayTokenSendRequestOpReturnData'
    }

    attribute_map = {
        'wallet_id': 'walletId',
        'amount': 'amount',
        'capability': 'capability',
        'commitment': 'commitment',
        'cashaddr': 'cashaddr',
        'value': 'value',
        'send_requests': 'sendRequests'
    }

    def __init__(self, wallet_id=None, amount=None, capability=None, commitment=None, cashaddr=None, value=1000, send_requests=None, local_vars_configuration=None):  # noqa: E501
        """TokenGenesisRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._wallet_id = None
        self._amount = None
        self._capability = None
        self._commitment = None
        self._cashaddr = None
        self._value = None
        self._send_requests = None
        self.discriminator = None

        self.wallet_id = wallet_id
        if amount is not None:
            self.amount = amount
        if capability is not None:
            self.capability = capability
        if commitment is not None:
            self.commitment = commitment
        if cashaddr is not None:
            self.cashaddr = cashaddr
        if value is not None:
            self.value = value
        if send_requests is not None:
            self.send_requests = send_requests

    @property
    def wallet_id(self):
        """Gets the wallet_id of this TokenGenesisRequest.  # noqa: E501

        The walletId to make a request to.  # noqa: E501

        :return: The wallet_id of this TokenGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._wallet_id

    @wallet_id.setter
    def wallet_id(self, wallet_id):
        """Sets the wallet_id of this TokenGenesisRequest.

        The walletId to make a request to.  # noqa: E501

        :param wallet_id: The wallet_id of this TokenGenesisRequest.  # noqa: E501
        :type wallet_id: str
        """
        if self.local_vars_configuration.client_side_validation and wallet_id is None:  # noqa: E501
            raise ValueError("Invalid value for `wallet_id`, must not be `None`")  # noqa: E501

        self._wallet_id = wallet_id

    @property
    def amount(self):
        """Gets the amount of this TokenGenesisRequest.  # noqa: E501

        amount of *fungible* tokens to create  # noqa: E501

        :return: The amount of this TokenGenesisRequest.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this TokenGenesisRequest.

        amount of *fungible* tokens to create  # noqa: E501

        :param amount: The amount of this TokenGenesisRequest.  # noqa: E501
        :type amount: float
        """

        self._amount = amount

    @property
    def capability(self):
        """Gets the capability of this TokenGenesisRequest.  # noqa: E501

        Capability of the new NFT  # noqa: E501

        :return: The capability of this TokenGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._capability

    @capability.setter
    def capability(self, capability):
        """Sets the capability of this TokenGenesisRequest.

        Capability of the new NFT  # noqa: E501

        :param capability: The capability of this TokenGenesisRequest.  # noqa: E501
        :type capability: str
        """
        allowed_values = ["none", "mutable", "minting"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and capability not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `capability` ({0}), must be one of {1}"  # noqa: E501
                .format(capability, allowed_values)
            )

        self._capability = capability

    @property
    def commitment(self):
        """Gets the commitment of this TokenGenesisRequest.  # noqa: E501

        Token commitment message, hexadecimal encoded, 40 bytes max length  # noqa: E501

        :return: The commitment of this TokenGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._commitment

    @commitment.setter
    def commitment(self, commitment):
        """Sets the commitment of this TokenGenesisRequest.

        Token commitment message, hexadecimal encoded, 40 bytes max length  # noqa: E501

        :param commitment: The commitment of this TokenGenesisRequest.  # noqa: E501
        :type commitment: str
        """
        if (self.local_vars_configuration.client_side_validation and
                commitment is not None and len(commitment) > 80):
            raise ValueError("Invalid value for `commitment`, length must be less than or equal to `80`")  # noqa: E501

        self._commitment = commitment

    @property
    def cashaddr(self):
        """Gets the cashaddr of this TokenGenesisRequest.  # noqa: E501

        Cashaddress to send tokens to  # noqa: E501

        :return: The cashaddr of this TokenGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._cashaddr

    @cashaddr.setter
    def cashaddr(self, cashaddr):
        """Sets the cashaddr of this TokenGenesisRequest.

        Cashaddress to send tokens to  # noqa: E501

        :param cashaddr: The cashaddr of this TokenGenesisRequest.  # noqa: E501
        :type cashaddr: str
        """

        self._cashaddr = cashaddr

    @property
    def value(self):
        """Gets the value of this TokenGenesisRequest.  # noqa: E501

        Satoshi value to send alongside with tokens  # noqa: E501

        :return: The value of this TokenGenesisRequest.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this TokenGenesisRequest.

        Satoshi value to send alongside with tokens  # noqa: E501

        :param value: The value of this TokenGenesisRequest.  # noqa: E501
        :type value: float
        """

        self._value = value

    @property
    def send_requests(self):
        """Gets the send_requests of this TokenGenesisRequest.  # noqa: E501

        Single or an array of extra send requests (OP_RETURN, value transfer, etc.) to include in genesis transaction.  # noqa: E501

        :return: The send_requests of this TokenGenesisRequest.  # noqa: E501
        :rtype: AnyOfSendRequestItemarrayTokenSendRequestOpReturnData
        """
        return self._send_requests

    @send_requests.setter
    def send_requests(self, send_requests):
        """Sets the send_requests of this TokenGenesisRequest.

        Single or an array of extra send requests (OP_RETURN, value transfer, etc.) to include in genesis transaction.  # noqa: E501

        :param send_requests: The send_requests of this TokenGenesisRequest.  # noqa: E501
        :type send_requests: AnyOfSendRequestItemarrayTokenSendRequestOpReturnData
        """

        self._send_requests = send_requests

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TokenGenesisRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TokenGenesisRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.verify_signed_message_request import VerifySignedMessageRequest  # noqa: E501
from mainnet.rest import ApiException

class TestVerifySignedMessageRequest(unittest.TestCase):
    """VerifySignedMessageRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test VerifySignedMessageRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.verify_signed_message_request.VerifySignedMessageRequest()  # noqa: E501
        if include_optional :
            return VerifySignedMessageRequest(
                wallet_id = 'watch:mainnet:bitcoincash:qqehccy89v7ftlfgr9v0zvhjzyy7eatdkqt05lt3nw', 
                message = 'Chancellor on brink of second bailout for banks', 
                signature = IA+oq/uGz4kKA2bNgxPcM+T216abyUiBhofMg1J8fC5BLAbbIpF2toCHaO7/LQAxhQBtu5D6ROq1JjXiRwPAASg=, 
                public_key = '0'
            )
        else :
            return VerifySignedMessageRequest(
        )

    def testVerifySignedMessageRequest(self):
        """Test VerifySignedMessageRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class SmartBchOverrides(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'gas_limit': 'AnyOfnumberstring',
        'gas_price': 'AnyOfnumberstring',
        'max_fee_per_gas': 'AnyOfnumberstring',
        'max_priority_fee_per_gas': 'AnyOfnumberstring',
        'nonce': 'AnyOfnumberstring',
        'value': 'AnyOfnumberstring',
        'block_tag': 'AnyOfnumberstring',
        '_from': 'str'
    }

    attribute_map = {
        'gas_limit': 'gasLimit',
        'gas_price': 'gasPrice',
        'max_fee_per_gas': 'maxFeePerGas',
        'max_priority_fee_per_gas': 'maxPriorityFeePerGas',
        'nonce': 'nonce',
        'value': 'value',
        'block_tag': 'blockTag',
        '_from': 'from'
    }

    def __init__(self, gas_limit=None, gas_price=None, max_fee_per_gas=None, max_priority_fee_per_gas=None, nonce=None, value=None, block_tag=None, _from=None, local_vars_configuration=None):  # noqa: E501
        """SmartBchOverrides - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._gas_limit = None
        self._gas_price = None
        self._max_fee_per_gas = None
        self._max_priority_fee_per_gas = None
        self._nonce = None
        self._value = None
        self._block_tag = None
        self.__from = None
        self.discriminator = None

        if gas_limit is not None:
            self.gas_limit = gas_limit
        if gas_price is not None:
            self.gas_price = gas_price
        if max_fee_per_gas is not None:
            self.max_fee_per_gas = max_fee_per_gas
        if max_priority_fee_per_gas is not None:
            self.max_priority_fee_per_gas = max_priority_fee_per_gas
        if nonce is not None:
            self.nonce = nonce
        if value is not None:
            self.value = value
        if block_tag is not None:
            self.block_tag = block_tag
        if _from is not None:
            self._from = _from

    @property
    def gas_limit(self):
        """Gets the gas_limit of this SmartBchOverrides.  # noqa: E501


        :return: The gas_limit of this SmartBchOverrides.  # noqa: E501
        :rtype: AnyOfnumberstring
        """
        return self._gas_limit

    @gas_limit.setter
    def gas_limit(self, gas_limit):
        """Sets the gas_limit of this SmartBchOverrides.


        :param gas_limit: The gas_limit of this SmartBchOverrides.  # noqa: E501
        :type gas_limit: AnyOfnumberstring
        """

        self._gas_limit = gas_limit

    @property
    def gas_price(self):
        """Gets the gas_price of this SmartBchOverrides.  # noqa: E501


        :return: The gas_price of this SmartBchOverrides.  # noqa: E501
        :rtype: AnyOfnumberstring
        """
        return self._gas_price

    @gas_price.setter
    def gas_price(self, gas_price):
        """Sets the gas_price of this SmartBchOverrides.


        :param gas_price: The gas_price of this SmartBchOverrides.  # noqa: E501
        :type gas_price: AnyOfnumberstring
        """

        self._gas_price = gas_price

    @property
    def max_fee_per_gas(self):
        """Gets the max_fee_per_gas of this SmartBchOverrides.  # noqa: E501


        :return: The max_fee_per_gas of this SmartBchOverrides.  # noqa: E501
        :rtype: AnyOfnumberstring
        """
        return self._max_fee_per_gas

    @max_fee_per_gas.setter
    def max_fee_per_gas(self, max_fee_per_gas):
        """Sets the max_fee_per_gas of this SmartBchOverrides.


        :param max_fee_per_gas: The max_fee_per_gas of this SmartBchOverrides.  # noqa: E501
        :type max_fee_per_gas: AnyOfnumberstring
        """

        self._max_fee_per_gas = max_fee_per_gas

    @property
    def max_priority_fee_per_gas(self):
        """Gets the max_priority_fee_per_gas of this SmartBchOverrides.  # noqa: E501


        :return: The max_priority_fee_per_gas of this SmartBchOverrides.  # noqa: E501
        :rtype: AnyOfnumberstring
        """
        return self._max_priority_fee_per_gas

    @max_priority_fee_per_gas.setter
    def max_priority_fee_per_gas(self, max_priority_fee_per_gas):
        """Sets the max_priority_fee_per_gas of this SmartBchOverrides.


        :param max_priority_fee_per_gas: The max_priority_fee_per_gas of this SmartBchOverrides.  # noqa: E501
        :type max_priority_fee_per_gas: AnyOfnumberstring
        """

        self._max_priority_fee_per_gas = max_priority_fee_per_gas

    @property
    def nonce(self):
        """Gets the nonce of this SmartBchOverrides.  # noqa: E501


        :return: The nonce of this SmartBchOverrides.  # noqa: E501
        :rtype: AnyOfnumberstring
        """
        return self._nonce

    @nonce.setter
    def nonce(self, nonce):
        """Sets the nonce of this SmartBchOverrides.


        :param nonce: The nonce of this SmartBchOverrides.  # noqa: E501
        :type nonce: AnyOfnumberstring
        """

        self._nonce = nonce

    @property
    def value(self):
        """Gets the value of this SmartBchOverrides.  # noqa: E501


        :return: The value of this SmartBchOverrides.  # noqa: E501
        :rtype: AnyOfnumberstring
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this SmartBchOverrides.


        :param value: The value of this SmartBchOverrides.  # noqa: E501
        :type value: AnyOfnumberstring
        """

        self._value = value

    @property
    def block_tag(self):
        """Gets the block_tag of this SmartBchOverrides.  # noqa: E501


        :return: The block_tag of this SmartBchOverrides.  # noqa: E501
        :rtype: AnyOfnumberstring
        """
        return self._block_tag

    @block_tag.setter
    def block_tag(self, block_tag):
        """Sets the block_tag of this SmartBchOverrides.


        :param block_tag: The block_tag of this SmartBchOverrides.  # noqa: E501
        :type block_tag: AnyOfnumberstring
        """

        self._block_tag = block_tag

    @property
    def _from(self):
        """Gets the _from of this SmartBchOverrides.  # noqa: E501


        :return: The _from of this SmartBchOverrides.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this SmartBchOverrides.


        :param _from: The _from of this SmartBchOverrides.  # noqa: E501
        :type _from: str
        """

        self.__from = _from

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmartBchOverrides):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SmartBchOverrides):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.wallet_util_api import WalletUtilApi  # noqa: E501
from mainnet.rest import ApiException


class TestWalletUtilApi(unittest.TestCase):
    """WalletUtilApi unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.wallet_util_api.WalletUtilApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_util_decode_transaction(self):
        """Test case for util_decode_transaction

        Decode a bitcoin transaction. Accepts both transaction hash or raw transaction in hex format.  # noqa: E501
        """
        pass

    def test_util_get_raw_transaction(self):
        """Test case for util_get_raw_transaction

        Get bitcoin raw transaction  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.wallet_bcmr_api import WalletBcmrApi  # noqa: E501
from mainnet.rest import ApiException


class TestWalletBcmrApi(unittest.TestCase):
    """WalletBcmrApi unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.wallet_bcmr_api.WalletBcmrApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_bcmr_add_metadata_registry_auth_chain(self):
        """Test case for bcmr_add_metadata_registry_auth_chain

        Add BCMR metadata registry from autchain, returning the built chain  # noqa: E501
        """
        pass

    def test_bcmr_add_registry(self):
        """Test case for bcmr_add_registry

        Add BCMR registry from parameter  # noqa: E501
        """
        pass

    def test_bcmr_add_registry_from_uri(self):
        """Test case for bcmr_add_registry_from_uri

        Reset tracked BCMR registries  # noqa: E501
        """
        pass

    def test_bcmr_build_auth_chain(self):
        """Test case for bcmr_build_auth_chain

        Build a BCMR authchain  # noqa: E501
        """
        pass

    def test_bcmr_get_registries(self):
        """Test case for bcmr_get_registries

        Get tracked BCMR registries  # noqa: E501
        """
        pass

    def test_bcmr_get_token_info(self):
        """Test case for bcmr_get_token_info

        Get token info  # noqa: E501
        """
        pass

    def test_bcmr_reset_registries(self):
        """Test case for bcmr_reset_registries

        Reset tracked BCMR registries  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.smart_bch_sep20_genesis_request import SmartBchSep20GenesisRequest  # noqa: E501
from mainnet.rest import ApiException

class TestSmartBchSep20GenesisRequest(unittest.TestCase):
    """SmartBchSep20GenesisRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SmartBchSep20GenesisRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.smart_bch_sep20_genesis_request.SmartBchSep20GenesisRequest()  # noqa: E501
        if include_optional :
            return SmartBchSep20GenesisRequest(
                wallet_id = 'privkey:regtest:0x758c7be51a76a9b6bc6b3e1a90e5ff4cc27aa054b77b7acb6f4f08a219c1ce45', 
                name = 'Mainnet coin', 
                ticker = 'MNC', 
                initial_amount = 10000, 
                decimals = 1.337, 
                end_baton = False, 
                token_receiver_address = '0xE25ddbAF8DD61b627727e03e190E32feddBD1319', 
                baton_receiver_address = '0xE25ddbAF8DD61b627727e03e190E32feddBD1319', 
                overrides = mainnet.models.smart_bch_overrides.SmartBchOverrides(
                    gas_limit = null, 
                    gas_price = null, 
                    max_fee_per_gas = null, 
                    max_priority_fee_per_gas = null, 
                    nonce = null, 
                    value = null, 
                    block_tag = null, 
                    from = '0', )
            )
        else :
            return SmartBchSep20GenesisRequest(
                wallet_id = 'privkey:regtest:0x758c7be51a76a9b6bc6b3e1a90e5ff4cc27aa054b77b7acb6f4f08a219c1ce45',
                name = 'Mainnet coin',
                ticker = 'MNC',
                initial_amount = 10000,
                decimals = 1.337,
        )

    def testSmartBchSep20GenesisRequest(self):
        """Test SmartBchSep20GenesisRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.smart_bch_contract_deploy_response import SmartBchContractDeployResponse  # noqa: E501
from mainnet.rest import ApiException

class TestSmartBchContractDeployResponse(unittest.TestCase):
    """SmartBchContractDeployResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SmartBchContractDeployResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.smart_bch_contract_deploy_response.SmartBchContractDeployResponse()  # noqa: E501
        if include_optional :
            return SmartBchContractDeployResponse(
                contract_id = '0', 
                address = '0xE25ddbAF8DD61b627727e03e190E32feddBD1319', 
                tx_id = '0xc519c3b66955a598dd1f298fcfaf92530db39b70d6d4699c57ffc5faa5aa30f7', 
                receipt = mainnet.models.smart_bch_transaction_receipt.SmartBchTransactionReceipt(
                    to = '0', 
                    from = '0', 
                    contract_address = '0', 
                    transaction_index = 1.337, 
                    root = '0', 
                    gas_used = '0', 
                    logs_bloom = '0', 
                    block_hash = '0', 
                    transaction_hash = '0', 
                    logs = [
                        null
                        ], 
                    block_number = 1.337, 
                    confirmations = 1.337, 
                    cumulative_gas_used = '0', 
                    effective_gas_price = '0', 
                    byzantium = True, 
                    type = 1.337, 
                    status = 1.337, )
            )
        else :
            return SmartBchContractDeployResponse(
        )

    def testSmartBchContractDeployResponse(self):
        """Test SmartBchContractDeployResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class UtilDecodeTransactionRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'transaction_hash_or_hex': 'str',
        'load_input_values': 'bool'
    }

    attribute_map = {
        'transaction_hash_or_hex': 'transactionHashOrHex',
        'load_input_values': 'loadInputValues'
    }

    def __init__(self, transaction_hash_or_hex=None, load_input_values=None, local_vars_configuration=None):  # noqa: E501
        """UtilDecodeTransactionRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._transaction_hash_or_hex = None
        self._load_input_values = None
        self.discriminator = None

        self.transaction_hash_or_hex = transaction_hash_or_hex
        if load_input_values is not None:
            self.load_input_values = load_input_values

    @property
    def transaction_hash_or_hex(self):
        """Gets the transaction_hash_or_hex of this UtilDecodeTransactionRequest.  # noqa: E501


        :return: The transaction_hash_or_hex of this UtilDecodeTransactionRequest.  # noqa: E501
        :rtype: str
        """
        return self._transaction_hash_or_hex

    @transaction_hash_or_hex.setter
    def transaction_hash_or_hex(self, transaction_hash_or_hex):
        """Sets the transaction_hash_or_hex of this UtilDecodeTransactionRequest.


        :param transaction_hash_or_hex: The transaction_hash_or_hex of this UtilDecodeTransactionRequest.  # noqa: E501
        :type transaction_hash_or_hex: str
        """
        if self.local_vars_configuration.client_side_validation and transaction_hash_or_hex is None:  # noqa: E501
            raise ValueError("Invalid value for `transaction_hash_or_hex`, must not be `None`")  # noqa: E501

        self._transaction_hash_or_hex = transaction_hash_or_hex

    @property
    def load_input_values(self):
        """Gets the load_input_values of this UtilDecodeTransactionRequest.  # noqa: E501

        A flag whether to load or not extra information about transaction inputs (cashaddress and value)  # noqa: E501

        :return: The load_input_values of this UtilDecodeTransactionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._load_input_values

    @load_input_values.setter
    def load_input_values(self, load_input_values):
        """Sets the load_input_values of this UtilDecodeTransactionRequest.

        A flag whether to load or not extra information about transaction inputs (cashaddress and value)  # noqa: E501

        :param load_input_values: The load_input_values of this UtilDecodeTransactionRequest.  # noqa: E501
        :type load_input_values: bool
        """

        self._load_input_values = load_input_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UtilDecodeTransactionRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UtilDecodeTransactionRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.smart_bch_contract_fn_call_request import SmartBchContractFnCallRequest  # noqa: E501
from mainnet.rest import ApiException

class TestSmartBchContractFnCallRequest(unittest.TestCase):
    """SmartBchContractFnCallRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SmartBchContractFnCallRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.smart_bch_contract_fn_call_request.SmartBchContractFnCallRequest()  # noqa: E501
        if include_optional :
            return SmartBchContractFnCallRequest(
                wallet_id = 'privkey:regtest:0x758c7be51a76a9b6bc6b3e1a90e5ff4cc27aa054b77b7acb6f4f08a219c1ce45', 
                contract_id = '0', 
                function = '0', 
                arguments = [
                    null
                    ], 
                overrides = mainnet.models.smart_bch_overrides.SmartBchOverrides(
                    gas_limit = null, 
                    gas_price = null, 
                    max_fee_per_gas = null, 
                    max_priority_fee_per_gas = null, 
                    nonce = null, 
                    value = null, 
                    block_tag = null, 
                    from = '0', )
            )
        else :
            return SmartBchContractFnCallRequest(
                contract_id = '0',
                function = '0',
        )

    def testSmartBchContractFnCallRequest(self):
        """Test SmartBchContractFnCallRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class TransactionHistoryItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'to': 'str',
        '_from': 'str',
        'unit': 'UnitType',
        'index': 'float',
        'blockheight': 'float',
        'txn': 'str',
        'tx_id': 'str',
        'value': 'float',
        'fee': 'float',
        'balance': 'float'
    }

    attribute_map = {
        'to': 'to',
        '_from': 'from',
        'unit': 'unit',
        'index': 'index',
        'blockheight': 'blockheight',
        'txn': 'txn',
        'tx_id': 'txId',
        'value': 'value',
        'fee': 'fee',
        'balance': 'balance'
    }

    def __init__(self, to=None, _from=None, unit=None, index=None, blockheight=None, txn=None, tx_id=None, value=None, fee=None, balance=None, local_vars_configuration=None):  # noqa: E501
        """TransactionHistoryItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._to = None
        self.__from = None
        self._unit = None
        self._index = None
        self._blockheight = None
        self._txn = None
        self._tx_id = None
        self._value = None
        self._fee = None
        self._balance = None
        self.discriminator = None

        if to is not None:
            self.to = to
        if _from is not None:
            self._from = _from
        if unit is not None:
            self.unit = unit
        if index is not None:
            self.index = index
        if blockheight is not None:
            self.blockheight = blockheight
        if txn is not None:
            self.txn = txn
        if tx_id is not None:
            self.tx_id = tx_id
        if value is not None:
            self.value = value
        if fee is not None:
            self.fee = fee
        if balance is not None:
            self.balance = balance

    @property
    def to(self):
        """Gets the to of this TransactionHistoryItem.  # noqa: E501

        cashaddr of the receiving cash address.  # noqa: E501

        :return: The to of this TransactionHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this TransactionHistoryItem.

        cashaddr of the receiving cash address.  # noqa: E501

        :param to: The to of this TransactionHistoryItem.  # noqa: E501
        :type to: str
        """

        self._to = to

    @property
    def _from(self):
        """Gets the _from of this TransactionHistoryItem.  # noqa: E501

        cashaddr of the sending cash address.  # noqa: E501

        :return: The _from of this TransactionHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this TransactionHistoryItem.

        cashaddr of the sending cash address.  # noqa: E501

        :param _from: The _from of this TransactionHistoryItem.  # noqa: E501
        :type _from: str
        """

        self.__from = _from

    @property
    def unit(self):
        """Gets the unit of this TransactionHistoryItem.  # noqa: E501


        :return: The unit of this TransactionHistoryItem.  # noqa: E501
        :rtype: UnitType
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this TransactionHistoryItem.


        :param unit: The unit of this TransactionHistoryItem.  # noqa: E501
        :type unit: UnitType
        """

        self._unit = unit

    @property
    def index(self):
        """Gets the index of this TransactionHistoryItem.  # noqa: E501

        the index of the input or output in the transaction  # noqa: E501

        :return: The index of this TransactionHistoryItem.  # noqa: E501
        :rtype: float
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this TransactionHistoryItem.

        the index of the input or output in the transaction  # noqa: E501

        :param index: The index of this TransactionHistoryItem.  # noqa: E501
        :type index: float
        """

        self._index = index

    @property
    def blockheight(self):
        """Gets the blockheight of this TransactionHistoryItem.  # noqa: E501

        the blockheight of transaction  # noqa: E501

        :return: The blockheight of this TransactionHistoryItem.  # noqa: E501
        :rtype: float
        """
        return self._blockheight

    @blockheight.setter
    def blockheight(self, blockheight):
        """Sets the blockheight of this TransactionHistoryItem.

        the blockheight of transaction  # noqa: E501

        :param blockheight: The blockheight of this TransactionHistoryItem.  # noqa: E501
        :type blockheight: float
        """

        self._blockheight = blockheight

    @property
    def txn(self):
        """Gets the txn of this TransactionHistoryItem.  # noqa: E501

        The hash of the transaction  # noqa: E501

        :return: The txn of this TransactionHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._txn

    @txn.setter
    def txn(self, txn):
        """Sets the txn of this TransactionHistoryItem.

        The hash of the transaction  # noqa: E501

        :param txn: The txn of this TransactionHistoryItem.  # noqa: E501
        :type txn: str
        """

        self._txn = txn

    @property
    def tx_id(self):
        """Gets the tx_id of this TransactionHistoryItem.  # noqa: E501

        a unique identifier for the sub-transaction  # noqa: E501

        :return: The tx_id of this TransactionHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._tx_id

    @tx_id.setter
    def tx_id(self, tx_id):
        """Sets the tx_id of this TransactionHistoryItem.

        a unique identifier for the sub-transaction  # noqa: E501

        :param tx_id: The tx_id of this TransactionHistoryItem.  # noqa: E501
        :type tx_id: str
        """

        self._tx_id = tx_id

    @property
    def value(self):
        """Gets the value of this TransactionHistoryItem.  # noqa: E501

        The amount of the transaction, in the unit provided, with respect to the wallet provided.  # noqa: E501

        :return: The value of this TransactionHistoryItem.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this TransactionHistoryItem.

        The amount of the transaction, in the unit provided, with respect to the wallet provided.  # noqa: E501

        :param value: The value of this TransactionHistoryItem.  # noqa: E501
        :type value: float
        """

        self._value = value

    @property
    def fee(self):
        """Gets the fee of this TransactionHistoryItem.  # noqa: E501

        The amount paid, if any, by the wallet for the transaction (incoming tranactions are \"free\")  # noqa: E501

        :return: The fee of this TransactionHistoryItem.  # noqa: E501
        :rtype: float
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this TransactionHistoryItem.

        The amount paid, if any, by the wallet for the transaction (incoming tranactions are \"free\")  # noqa: E501

        :param fee: The fee of this TransactionHistoryItem.  # noqa: E501
        :type fee: float
        """

        self._fee = fee

    @property
    def balance(self):
        """Gets the balance of this TransactionHistoryItem.  # noqa: E501

        A running balance  # noqa: E501

        :return: The balance of this TransactionHistoryItem.  # noqa: E501
        :rtype: float
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this TransactionHistoryItem.

        A running balance  # noqa: E501

        :param balance: The balance of this TransactionHistoryItem.  # noqa: E501
        :type balance: float
        """

        self._balance = balance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransactionHistoryItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TransactionHistoryItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class NetworkEnum(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'network': 'str'
    }

    attribute_map = {
        'network': 'network'
    }

    discriminator_value_class_map = {
        'WalletReplaceNamedRequest': 'WalletReplaceNamedRequest',
        'WalletNamedExistsRequest': 'WalletNamedExistsRequest',
        'UtilDecodeTransactionRequest': 'UtilDecodeTransactionRequest',
        'WalletInfo': 'WalletInfo',
        'WalletResponse': 'WalletResponse',
        'SmartBchContractRequest': 'SmartBchContractRequest',
        'ContractRequest': 'ContractRequest',
        'WalletRequest': 'WalletRequest'
    }

    def __init__(self, network=None, local_vars_configuration=None):  # noqa: E501
        """NetworkEnum - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._network = None
        self.discriminator = 'network'

        if network is not None:
            self.network = network

    @property
    def network(self):
        """Gets the network of this NetworkEnum.  # noqa: E501

        network type  # noqa: E501

        :return: The network of this NetworkEnum.  # noqa: E501
        :rtype: str
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this NetworkEnum.

        network type  # noqa: E501

        :param network: The network of this NetworkEnum.  # noqa: E501
        :type network: str
        """
        allowed_values = ["mainnet", "testnet", "regtest"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and network not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `network` ({0}), must be one of {1}"  # noqa: E501
                .format(network, allowed_values)
            )

        self._network = network

    def get_real_child_model(self, data):
        """Returns the real base class specified by the discriminator"""
        discriminator_key = self.attribute_map[self.discriminator]
        discriminator_value = data[discriminator_key]
        return self.discriminator_value_class_map.get(discriminator_value)

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkEnum):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NetworkEnum):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.electrum_raw_transaction_vout import ElectrumRawTransactionVout  # noqa: E501
from mainnet.rest import ApiException

class TestElectrumRawTransactionVout(unittest.TestCase):
    """ElectrumRawTransactionVout unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ElectrumRawTransactionVout
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.electrum_raw_transaction_vout.ElectrumRawTransactionVout()  # noqa: E501
        if include_optional :
            return ElectrumRawTransactionVout(
                n = 1.337, 
                script_pub_key = mainnet.models.electrum_raw_transaction_script_pub_key.ElectrumRawTransaction_scriptPubKey(
                    addresses = [
                        '0'
                        ], 
                    asm = '0', 
                    hex = '0', 
                    req_sigs = 1.337, 
                    type = '0', ), 
                value = 1.337
            )
        else :
            return ElectrumRawTransactionVout(
        )

    def testElectrumRawTransactionVout(self):
        """Test ElectrumRawTransactionVout"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mainnet.api_client import ApiClient
from mainnet.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class WalletBcmrApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def bcmr_add_metadata_registry_auth_chain(self, unknown_base_type, **kwargs):  # noqa: E501
        """Add BCMR metadata registry from autchain, returning the built chain  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_add_metadata_registry_auth_chain(unknown_base_type, async_req=True)
        >>> result = thread.get()

        :param unknown_base_type: Add BCMR metadata registry by resolving an authchain, allowing for token info lookup  (required)
        :type unknown_base_type: UNKNOWN_BASE_TYPE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[AuthChainElement]
        """
        kwargs['_return_http_data_only'] = True
        return self.bcmr_add_metadata_registry_auth_chain_with_http_info(unknown_base_type, **kwargs)  # noqa: E501

    def bcmr_add_metadata_registry_auth_chain_with_http_info(self, unknown_base_type, **kwargs):  # noqa: E501
        """Add BCMR metadata registry from autchain, returning the built chain  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_add_metadata_registry_auth_chain_with_http_info(unknown_base_type, async_req=True)
        >>> result = thread.get()

        :param unknown_base_type: Add BCMR metadata registry by resolving an authchain, allowing for token info lookup  (required)
        :type unknown_base_type: UNKNOWN_BASE_TYPE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(list[AuthChainElement], status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'unknown_base_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method bcmr_add_metadata_registry_auth_chain" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'unknown_base_type' is set
        if self.api_client.client_side_validation and ('unknown_base_type' not in local_var_params or  # noqa: E501
                                                        local_var_params['unknown_base_type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `unknown_base_type` when calling `bcmr_add_metadata_registry_auth_chain`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'unknown_base_type' in local_var_params:
            body_params = local_var_params['unknown_base_type']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/wallet/bcmr/add_registry_authchain', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AuthChainElement]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def bcmr_add_registry(self, request_body, **kwargs):  # noqa: E501
        """Add BCMR registry from parameter  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_add_registry(request_body, async_req=True)
        >>> result = thread.get()

        :param request_body: Add a BCMR registry to the list of tracked, allowing for token info lookup  (required)
        :type request_body: dict(str, object)
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        return self.bcmr_add_registry_with_http_info(request_body, **kwargs)  # noqa: E501

    def bcmr_add_registry_with_http_info(self, request_body, **kwargs):  # noqa: E501
        """Add BCMR registry from parameter  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_add_registry_with_http_info(request_body, async_req=True)
        >>> result = thread.get()

        :param request_body: Add a BCMR registry to the list of tracked, allowing for token info lookup  (required)
        :type request_body: dict(str, object)
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method bcmr_add_registry" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'request_body' is set
        if self.api_client.client_side_validation and ('request_body' not in local_var_params or  # noqa: E501
                                                        local_var_params['request_body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `request_body` when calling `bcmr_add_registry`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/wallet/bcmr/add_registry', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def bcmr_add_registry_from_uri(self, unknown_base_type, **kwargs):  # noqa: E501
        """Reset tracked BCMR registries  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_add_registry_from_uri(unknown_base_type, async_req=True)
        >>> result = thread.get()

        :param unknown_base_type: Add a BCMR registry from remote URI to the list of tracked, allowing for token info lookup  (required)
        :type unknown_base_type: UNKNOWN_BASE_TYPE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        return self.bcmr_add_registry_from_uri_with_http_info(unknown_base_type, **kwargs)  # noqa: E501

    def bcmr_add_registry_from_uri_with_http_info(self, unknown_base_type, **kwargs):  # noqa: E501
        """Reset tracked BCMR registries  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_add_registry_from_uri_with_http_info(unknown_base_type, async_req=True)
        >>> result = thread.get()

        :param unknown_base_type: Add a BCMR registry from remote URI to the list of tracked, allowing for token info lookup  (required)
        :type unknown_base_type: UNKNOWN_BASE_TYPE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'unknown_base_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method bcmr_add_registry_from_uri" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'unknown_base_type' is set
        if self.api_client.client_side_validation and ('unknown_base_type' not in local_var_params or  # noqa: E501
                                                        local_var_params['unknown_base_type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `unknown_base_type` when calling `bcmr_add_registry_from_uri`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'unknown_base_type' in local_var_params:
            body_params = local_var_params['unknown_base_type']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/wallet/bcmr/add_registry_from_uri', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def bcmr_build_auth_chain(self, unknown_base_type, **kwargs):  # noqa: E501
        """Build a BCMR authchain  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_build_auth_chain(unknown_base_type, async_req=True)
        >>> result = thread.get()

        :param unknown_base_type: Build an authchain - Zeroth-Descendant Transaction Chain, refer to https://github.com/bitjson/chip-bcmr#zeroth-descendant-transaction-chains The authchain in this implementation is specific to resolve to a valid metadata registy  (required)
        :type unknown_base_type: UNKNOWN_BASE_TYPE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[AuthChainElement]
        """
        kwargs['_return_http_data_only'] = True
        return self.bcmr_build_auth_chain_with_http_info(unknown_base_type, **kwargs)  # noqa: E501

    def bcmr_build_auth_chain_with_http_info(self, unknown_base_type, **kwargs):  # noqa: E501
        """Build a BCMR authchain  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_build_auth_chain_with_http_info(unknown_base_type, async_req=True)
        >>> result = thread.get()

        :param unknown_base_type: Build an authchain - Zeroth-Descendant Transaction Chain, refer to https://github.com/bitjson/chip-bcmr#zeroth-descendant-transaction-chains The authchain in this implementation is specific to resolve to a valid metadata registy  (required)
        :type unknown_base_type: UNKNOWN_BASE_TYPE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(list[AuthChainElement], status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'unknown_base_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method bcmr_build_auth_chain" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'unknown_base_type' is set
        if self.api_client.client_side_validation and ('unknown_base_type' not in local_var_params or  # noqa: E501
                                                        local_var_params['unknown_base_type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `unknown_base_type` when calling `bcmr_build_auth_chain`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'unknown_base_type' in local_var_params:
            body_params = local_var_params['unknown_base_type']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/wallet/bcmr/build_authchain', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AuthChainElement]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def bcmr_get_registries(self, **kwargs):  # noqa: E501
        """Get tracked BCMR registries  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_get_registries(async_req=True)
        >>> result = thread.get()

        :param request_body: Get tracked BCMR registries. 
        :type request_body: dict(str, object)
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[dict(str, object)]
        """
        kwargs['_return_http_data_only'] = True
        return self.bcmr_get_registries_with_http_info(**kwargs)  # noqa: E501

    def bcmr_get_registries_with_http_info(self, **kwargs):  # noqa: E501
        """Get tracked BCMR registries  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_get_registries_with_http_info(async_req=True)
        >>> result = thread.get()

        :param request_body: Get tracked BCMR registries. 
        :type request_body: dict(str, object)
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(list[dict(str, object)], status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method bcmr_get_registries" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/wallet/bcmr/get_registries', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[dict(str, object)]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def bcmr_get_token_info(self, unknown_base_type, **kwargs):  # noqa: E501
        """Get token info  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_get_token_info(unknown_base_type, async_req=True)
        >>> result = thread.get()

        :param unknown_base_type: Return the token info (the identity snapshot as per BCMR spec)  (required)
        :type unknown_base_type: UNKNOWN_BASE_TYPE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        return self.bcmr_get_token_info_with_http_info(unknown_base_type, **kwargs)  # noqa: E501

    def bcmr_get_token_info_with_http_info(self, unknown_base_type, **kwargs):  # noqa: E501
        """Get token info  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_get_token_info_with_http_info(unknown_base_type, async_req=True)
        >>> result = thread.get()

        :param unknown_base_type: Return the token info (the identity snapshot as per BCMR spec)  (required)
        :type unknown_base_type: UNKNOWN_BASE_TYPE
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'unknown_base_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method bcmr_get_token_info" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'unknown_base_type' is set
        if self.api_client.client_side_validation and ('unknown_base_type' not in local_var_params or  # noqa: E501
                                                        local_var_params['unknown_base_type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `unknown_base_type` when calling `bcmr_get_token_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'unknown_base_type' in local_var_params:
            body_params = local_var_params['unknown_base_type']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/wallet/bcmr/get_token_info', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def bcmr_reset_registries(self, **kwargs):  # noqa: E501
        """Reset tracked BCMR registries  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_reset_registries(async_req=True)
        >>> result = thread.get()

        :param body: Reset tracked BCMR registries, dropping all token info. 
        :type body: object
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        return self.bcmr_reset_registries_with_http_info(**kwargs)  # noqa: E501

    def bcmr_reset_registries_with_http_info(self, **kwargs):  # noqa: E501
        """Reset tracked BCMR registries  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bcmr_reset_registries_with_http_info(async_req=True)
        >>> result = thread.get()

        :param body: Reset tracked BCMR registries, dropping all token info. 
        :type body: object
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method bcmr_reset_registries" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/wallet/bcmr/reset_registries', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.faucet_api import FaucetApi  # noqa: E501
from mainnet.rest import ApiException


class TestFaucetApi(unittest.TestCase):
    """FaucetApi unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.faucet_api.FaucetApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_addresses(self):
        """Test case for get_addresses

        Get addresses to return back or donate the testnet bch and tokens   # noqa: E501
        """
        pass

    def test_get_testnet_bch(self):
        """Test case for get_testnet_bch

        Get testnet bch   # noqa: E501
        """
        pass

    def test_get_testnet_sbch(self):
        """Test case for get_testnet_sbch

        Request testnet SmartBCH funds. The request is enqueued and served within 1-3 block confirmations. If the target address holds more that 0.1 BCH, the request will fail. Otherwise the address will be topped up to 0.1 BCH.   # noqa: E501
        """
        pass

    def test_get_testnet_sep20(self):
        """Test case for get_testnet_sep20

        Request testnet SmartBch SEP20 tokens. The request is enqueued and served within 1-3 block confirmations. If the target address holds more that 10 tokens of requested kind, the request will fail. Otherwise the address will be topped up to 10 tokens.   # noqa: E501
        """
        pass

    def test_get_testnet_slp(self):
        """Test case for get_testnet_slp

        Get testnet slp tokens   # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mainnet.api_client import ApiClient
from mainnet.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class FaucetApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_addresses(self, **kwargs):  # noqa: E501
        """Get addresses to return back or donate the testnet bch and tokens   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_addresses(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetAddressesResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_addresses_with_http_info(**kwargs)  # noqa: E501

    def get_addresses_with_http_info(self, **kwargs):  # noqa: E501
        """Get addresses to return back or donate the testnet bch and tokens   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_addresses_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetAddressesResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_addresses" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/faucet/get_addresses', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAddressesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_testnet_bch(self, get_testnet_bch_request, **kwargs):  # noqa: E501
        """Get testnet bch   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_testnet_bch(get_testnet_bch_request, async_req=True)
        >>> result = thread.get()

        :param get_testnet_bch_request: Request to bch faucet  (required)
        :type get_testnet_bch_request: GetTestnetBchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetTestnetBchResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_testnet_bch_with_http_info(get_testnet_bch_request, **kwargs)  # noqa: E501

    def get_testnet_bch_with_http_info(self, get_testnet_bch_request, **kwargs):  # noqa: E501
        """Get testnet bch   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_testnet_bch_with_http_info(get_testnet_bch_request, async_req=True)
        >>> result = thread.get()

        :param get_testnet_bch_request: Request to bch faucet  (required)
        :type get_testnet_bch_request: GetTestnetBchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetTestnetBchResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'get_testnet_bch_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_testnet_bch" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'get_testnet_bch_request' is set
        if self.api_client.client_side_validation and ('get_testnet_bch_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['get_testnet_bch_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `get_testnet_bch_request` when calling `get_testnet_bch`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_testnet_bch_request' in local_var_params:
            body_params = local_var_params['get_testnet_bch_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/faucet/get_testnet_bch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetTestnetBchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_testnet_sbch(self, get_testnet_sbch_request, **kwargs):  # noqa: E501
        """Request testnet SmartBCH funds. The request is enqueued and served within 1-3 block confirmations. If the target address holds more that 0.1 BCH, the request will fail. Otherwise the address will be topped up to 0.1 BCH.   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_testnet_sbch(get_testnet_sbch_request, async_req=True)
        >>> result = thread.get()

        :param get_testnet_sbch_request: Request to bch faucet  (required)
        :type get_testnet_sbch_request: GetTestnetSbchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetTestnetSbchResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_testnet_sbch_with_http_info(get_testnet_sbch_request, **kwargs)  # noqa: E501

    def get_testnet_sbch_with_http_info(self, get_testnet_sbch_request, **kwargs):  # noqa: E501
        """Request testnet SmartBCH funds. The request is enqueued and served within 1-3 block confirmations. If the target address holds more that 0.1 BCH, the request will fail. Otherwise the address will be topped up to 0.1 BCH.   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_testnet_sbch_with_http_info(get_testnet_sbch_request, async_req=True)
        >>> result = thread.get()

        :param get_testnet_sbch_request: Request to bch faucet  (required)
        :type get_testnet_sbch_request: GetTestnetSbchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetTestnetSbchResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'get_testnet_sbch_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_testnet_sbch" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'get_testnet_sbch_request' is set
        if self.api_client.client_side_validation and ('get_testnet_sbch_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['get_testnet_sbch_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `get_testnet_sbch_request` when calling `get_testnet_sbch`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_testnet_sbch_request' in local_var_params:
            body_params = local_var_params['get_testnet_sbch_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/faucet/get_testnet_sbch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetTestnetSbchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_testnet_sep20(self, get_testnet_sep20_request, **kwargs):  # noqa: E501
        """Request testnet SmartBch SEP20 tokens. The request is enqueued and served within 1-3 block confirmations. If the target address holds more that 10 tokens of requested kind, the request will fail. Otherwise the address will be topped up to 10 tokens.   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_testnet_sep20(get_testnet_sep20_request, async_req=True)
        >>> result = thread.get()

        :param get_testnet_sep20_request: Request to SEP20 faucet  (required)
        :type get_testnet_sep20_request: GetTestnetSep20Request
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetTestnetSep20Response
        """
        kwargs['_return_http_data_only'] = True
        return self.get_testnet_sep20_with_http_info(get_testnet_sep20_request, **kwargs)  # noqa: E501

    def get_testnet_sep20_with_http_info(self, get_testnet_sep20_request, **kwargs):  # noqa: E501
        """Request testnet SmartBch SEP20 tokens. The request is enqueued and served within 1-3 block confirmations. If the target address holds more that 10 tokens of requested kind, the request will fail. Otherwise the address will be topped up to 10 tokens.   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_testnet_sep20_with_http_info(get_testnet_sep20_request, async_req=True)
        >>> result = thread.get()

        :param get_testnet_sep20_request: Request to SEP20 faucet  (required)
        :type get_testnet_sep20_request: GetTestnetSep20Request
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetTestnetSep20Response, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'get_testnet_sep20_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_testnet_sep20" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'get_testnet_sep20_request' is set
        if self.api_client.client_side_validation and ('get_testnet_sep20_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['get_testnet_sep20_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `get_testnet_sep20_request` when calling `get_testnet_sep20`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_testnet_sep20_request' in local_var_params:
            body_params = local_var_params['get_testnet_sep20_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/faucet/get_testnet_sep20', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetTestnetSep20Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_testnet_slp(self, get_testnet_slp_request, **kwargs):  # noqa: E501
        """Get testnet slp tokens   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_testnet_slp(get_testnet_slp_request, async_req=True)
        >>> result = thread.get()

        :param get_testnet_slp_request: Request to slp faucet  (required)
        :type get_testnet_slp_request: GetTestnetSlpRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetTestnetSlpResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_testnet_slp_with_http_info(get_testnet_slp_request, **kwargs)  # noqa: E501

    def get_testnet_slp_with_http_info(self, get_testnet_slp_request, **kwargs):  # noqa: E501
        """Get testnet slp tokens   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_testnet_slp_with_http_info(get_testnet_slp_request, async_req=True)
        >>> result = thread.get()

        :param get_testnet_slp_request: Request to slp faucet  (required)
        :type get_testnet_slp_request: GetTestnetSlpRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetTestnetSlpResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'get_testnet_slp_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_testnet_slp" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'get_testnet_slp_request' is set
        if self.api_client.client_side_validation and ('get_testnet_slp_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['get_testnet_slp_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `get_testnet_slp_request` when calling `get_testnet_slp`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_testnet_slp_request' in local_var_params:
            body_params = local_var_params['get_testnet_slp_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/faucet/get_testnet_slp', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetTestnetSlpResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.smart_bch_transaction_receipt import SmartBchTransactionReceipt  # noqa: E501
from mainnet.rest import ApiException

class TestSmartBchTransactionReceipt(unittest.TestCase):
    """SmartBchTransactionReceipt unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SmartBchTransactionReceipt
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.smart_bch_transaction_receipt.SmartBchTransactionReceipt()  # noqa: E501
        if include_optional :
            return SmartBchTransactionReceipt(
                to = '0', 
                _from = '0', 
                contract_address = '0', 
                transaction_index = 1.337, 
                root = '0', 
                gas_used = '0', 
                logs_bloom = '0', 
                block_hash = '0', 
                transaction_hash = '0', 
                logs = [
                    null
                    ], 
                block_number = 1.337, 
                confirmations = 1.337, 
                cumulative_gas_used = '0', 
                effective_gas_price = '0', 
                byzantium = True, 
                type = 1.337, 
                status = 1.337
            )
        else :
            return SmartBchTransactionReceipt(
                to = '0',
                _from = '0',
                contract_address = '0',
                transaction_index = 1.337,
                gas_used = '0',
                logs_bloom = '0',
                block_hash = '0',
                transaction_hash = '0',
                logs = [
                    null
                    ],
                block_number = 1.337,
                confirmations = 1.337,
                cumulative_gas_used = '0',
                effective_gas_price = '0',
                byzantium = True,
                type = 1.337,
        )

    def testSmartBchTransactionReceipt(self):
        """Test SmartBchTransactionReceipt"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 1.1.16
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class SendRequestOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'utxo_ids': 'list[str]',
        'change_address': 'str',
        'slp_aware': 'bool',
        'slp_semi_aware': 'bool',
        'query_balance': 'bool',
        'await_transaction_propagation': 'bool',
        'fee_paid_by': 'str',
        'check_token_quantities': 'bool'
    }

    attribute_map = {
        'utxo_ids': 'utxoIds',
        'change_address': 'changeAddress',
        'slp_aware': 'slpAware',
        'slp_semi_aware': 'slpSemiAware',
        'query_balance': 'queryBalance',
        'await_transaction_propagation': 'awaitTransactionPropagation',
        'fee_paid_by': 'feePaidBy',
        'check_token_quantities': 'checkTokenQuantities'
    }

    def __init__(self, utxo_ids=None, change_address=None, slp_aware=False, slp_semi_aware=False, query_balance=True, await_transaction_propagation=True, fee_paid_by='change', check_token_quantities=True, local_vars_configuration=None):  # noqa: E501
        """SendRequestOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._utxo_ids = None
        self._change_address = None
        self._slp_aware = None
        self._slp_semi_aware = None
        self._query_balance = None
        self._await_transaction_propagation = None
        self._fee_paid_by = None
        self._check_token_quantities = None
        self.discriminator = None

        if utxo_ids is not None:
            self.utxo_ids = utxo_ids
        if change_address is not None:
            self.change_address = change_address
        if slp_aware is not None:
            self.slp_aware = slp_aware
        if slp_semi_aware is not None:
            self.slp_semi_aware = slp_semi_aware
        if query_balance is not None:
            self.query_balance = query_balance
        if await_transaction_propagation is not None:
            self.await_transaction_propagation = await_transaction_propagation
        if fee_paid_by is not None:
            self.fee_paid_by = fee_paid_by
        if check_token_quantities is not None:
            self.check_token_quantities = check_token_quantities

    @property
    def utxo_ids(self):
        """Gets the utxo_ids of this SendRequestOptions.  # noqa: E501


        :return: The utxo_ids of this SendRequestOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._utxo_ids

    @utxo_ids.setter
    def utxo_ids(self, utxo_ids):
        """Sets the utxo_ids of this SendRequestOptions.


        :param utxo_ids: The utxo_ids of this SendRequestOptions.  # noqa: E501
        :type utxo_ids: list[str]
        """

        self._utxo_ids = utxo_ids

    @property
    def change_address(self):
        """Gets the change_address of this SendRequestOptions.  # noqa: E501

        Cash address to receive change to   # noqa: E501

        :return: The change_address of this SendRequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._change_address

    @change_address.setter
    def change_address(self, change_address):
        """Sets the change_address of this SendRequestOptions.

        Cash address to receive change to   # noqa: E501

        :param change_address: The change_address of this SendRequestOptions.  # noqa: E501
        :type change_address: str
        """

        self._change_address = change_address

    @property
    def slp_aware(self):
        """Gets the slp_aware of this SendRequestOptions.  # noqa: E501

        If you have any SLP tokens on the address, you should set `slpAware` to `true` to prevent accidental token burning This flag activates utxo checking against an external slp indexer So far this option is not switched on by default  # noqa: E501

        :return: The slp_aware of this SendRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._slp_aware

    @slp_aware.setter
    def slp_aware(self, slp_aware):
        """Sets the slp_aware of this SendRequestOptions.

        If you have any SLP tokens on the address, you should set `slpAware` to `true` to prevent accidental token burning This flag activates utxo checking against an external slp indexer So far this option is not switched on by default  # noqa: E501

        :param slp_aware: The slp_aware of this SendRequestOptions.  # noqa: E501
        :type slp_aware: bool
        """

        self._slp_aware = slp_aware

    @property
    def slp_semi_aware(self):
        """Gets the slp_semi_aware of this SendRequestOptions.  # noqa: E501

        This flag requires an utxo to have more than 546 sats to be spendable and counted in the balance This option is not switched on by default  # noqa: E501

        :return: The slp_semi_aware of this SendRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._slp_semi_aware

    @slp_semi_aware.setter
    def slp_semi_aware(self, slp_semi_aware):
        """Sets the slp_semi_aware of this SendRequestOptions.

        This flag requires an utxo to have more than 546 sats to be spendable and counted in the balance This option is not switched on by default  # noqa: E501

        :param slp_semi_aware: The slp_semi_aware of this SendRequestOptions.  # noqa: E501
        :type slp_semi_aware: bool
        """

        self._slp_semi_aware = slp_semi_aware

    @property
    def query_balance(self):
        """Gets the query_balance of this SendRequestOptions.  # noqa: E501

        A boolean flag to include the wallet balance after the successful `send` operation to the returned result If set to false, the balance will not be queried and returned, making the `send` call faster  # noqa: E501

        :return: The query_balance of this SendRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._query_balance

    @query_balance.setter
    def query_balance(self, query_balance):
        """Sets the query_balance of this SendRequestOptions.

        A boolean flag to include the wallet balance after the successful `send` operation to the returned result If set to false, the balance will not be queried and returned, making the `send` call faster  # noqa: E501

        :param query_balance: The query_balance of this SendRequestOptions.  # noqa: E501
        :type query_balance: bool
        """

        self._query_balance = query_balance

    @property
    def await_transaction_propagation(self):
        """Gets the await_transaction_propagation of this SendRequestOptions.  # noqa: E501

        A boolean flag to wait for transaction to propagate through the network and be registered in the bitcoind and indexer. If set to false, the `send` call will be very fast, but the wallet UTXO state might be invalid for some 500ms.  # noqa: E501

        :return: The await_transaction_propagation of this SendRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._await_transaction_propagation

    @await_transaction_propagation.setter
    def await_transaction_propagation(self, await_transaction_propagation):
        """Sets the await_transaction_propagation of this SendRequestOptions.

        A boolean flag to wait for transaction to propagate through the network and be registered in the bitcoind and indexer. If set to false, the `send` call will be very fast, but the wallet UTXO state might be invalid for some 500ms.  # noqa: E501

        :param await_transaction_propagation: The await_transaction_propagation of this SendRequestOptions.  # noqa: E501
        :type await_transaction_propagation: bool
        """

        self._await_transaction_propagation = await_transaction_propagation

    @property
    def fee_paid_by(self):
        """Gets the fee_paid_by of this SendRequestOptions.  # noqa: E501

        Fee allocation stragety. Convenience option to subtract fees from outputs if change is not sufficent to cover transaction costs.   * `change` - Change, pay the fees from change or error   * `firstOutput` - First Output, pay the fee from the first output or error   * `lastOutput` - Last Output, pay the fee from the last output or error   * `anyOutput` - Any Output, pay the fee from dust outputs or divide across all remaining non-dust outputs.   * `changeThenFirst` - Use change then first output or error.   * `changeThenLast` - Use change then last output or error.   * `changeThenAny` - Use change then any output stragety or error.   # noqa: E501

        :return: The fee_paid_by of this SendRequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._fee_paid_by

    @fee_paid_by.setter
    def fee_paid_by(self, fee_paid_by):
        """Sets the fee_paid_by of this SendRequestOptions.

        Fee allocation stragety. Convenience option to subtract fees from outputs if change is not sufficent to cover transaction costs.   * `change` - Change, pay the fees from change or error   * `firstOutput` - First Output, pay the fee from the first output or error   * `lastOutput` - Last Output, pay the fee from the last output or error   * `anyOutput` - Any Output, pay the fee from dust outputs or divide across all remaining non-dust outputs.   * `changeThenFirst` - Use change then first output or error.   * `changeThenLast` - Use change then last output or error.   * `changeThenAny` - Use change then any output stragety or error.   # noqa: E501

        :param fee_paid_by: The fee_paid_by of this SendRequestOptions.  # noqa: E501
        :type fee_paid_by: str
        """
        allowed_values = ["change", "firstOutput", "anyOutputs", "lastOutput", "changeThenFirst", "changeThenAny", "changeThenLast"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and fee_paid_by not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `fee_paid_by` ({0}), must be one of {1}"  # noqa: E501
                .format(fee_paid_by, allowed_values)
            )

        self._fee_paid_by = fee_paid_by

    @property
    def check_token_quantities(self):
        """Gets the check_token_quantities of this SendRequestOptions.  # noqa: E501

        Check that sum of input amounts and output amount for each token category matches. Prevents accidental burns.   # noqa: E501

        :return: The check_token_quantities of this SendRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_token_quantities

    @check_token_quantities.setter
    def check_token_quantities(self, check_token_quantities):
        """Sets the check_token_quantities of this SendRequestOptions.

        Check that sum of input amounts and output amount for each token category matches. Prevents accidental burns.   # noqa: E501

        :param check_token_quantities: The check_token_quantities of this SendRequestOptions.  # noqa: E501
        :type check_token_quantities: bool
        """

        self._check_token_quantities = check_token_quantities

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendRequestOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SendRequestOptions):
            return True

        return self.to_dict() != other.to_dict()
